@@ -1,21 +1,20 @@
-# -*- coding: utf-8 -*-
 """
     sphinx.util.parallel
     ~~~~~~~~~~~~~~~~~~~~
 
     Parallel building utilities.
 
-    :copyright: Copyright 2007-2019 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
-from __future__ import absolute_import
 
 import os
+import platform
+import sys
 import time
 import traceback
 from math import sqrt
-
-from six import iteritems
+from typing import Any, Callable, Dict, List, Sequence
 
 try:
     import multiprocessing
@@ -25,26 +24,25 @@ except ImportError:
 from sphinx.errors import SphinxParallelError
 from sphinx.util import logging
 
-if False:
-    # For type annotation
-    from typing import Any, Callable, Dict, List, Sequence  # NOQA
-
 logger = logging.getLogger(__name__)
 
 
 # our parallel functionality only works for the forking Process
-parallel_available = multiprocessing and (os.name == 'posix')
+#
+# Note: "fork" is not recommended on macOS and py38+.
+#       see https://bugs.python.org/issue33725
+parallel_available = (multiprocessing and
+                      (os.name == 'posix') and
+                      not (sys.version_info > (3, 8) and platform.system() == 'Darwin'))
 
 
-class SerialTasks(object):
+class SerialTasks:
     """Has the same interface as ParallelTasks, but executes tasks directly."""
 
-    def __init__(self, nproc=1):
-        # type: (int) -> None
+    def __init__(self, nproc: int = 1) -> None:
         pass
 
-    def add_task(self, task_func, arg=None, result_func=None):
-        # type: (Callable, Any, Callable) -> None
+    def add_task(self, task_func: Callable, arg: Any = None, result_func: Callable = None) -> None:  # NOQA
         if arg is not None:
             res = task_func(arg)
         else:
@@ -52,16 +50,14 @@ class SerialTasks(object):
         if result_func:
             result_func(res)
 
-    def join(self):
-        # type: () -> None
+    def join(self) -> None:
         pass
 
 
-class ParallelTasks(object):
+class ParallelTasks:
     """Executes *nproc* tasks in parallel after forking."""
 
-    def __init__(self, nproc):
-        # type: (int) -> None
+    def __init__(self, nproc: int) -> None:
         self.nproc = nproc
         # (optional) function performed by each task on the result of main task
         self._result_funcs = {}  # type: Dict[int, Callable]
@@ -78,8 +74,7 @@ class ParallelTasks(object):
         # task number of each subprocess
         self._taskid = 0
 
-    def _process(self, pipe, func, arg):
-        # type: (Any, Callable, Any) -> None
+    def _process(self, pipe: Any, func: Callable, arg: Any) -> None:
         try:
             collector = logging.LogCollector()
             with collector.collect():
@@ -95,8 +90,7 @@ class ParallelTasks(object):
         logging.convert_serializable(collector.logs)
         pipe.send((failed, collector.logs, ret))
 
-    def add_task(self, task_func, arg=None, result_func=None):
-        # type: (Callable, Any, Callable) -> None
+    def add_task(self, task_func: Callable, arg: Any = None, result_func: Callable = None) -> None:  # NOQA
         tid = self._taskid
         self._taskid += 1
         self._result_funcs[tid] = result_func or (lambda arg, result: None)
@@ -108,14 +102,12 @@ class ParallelTasks(object):
         self._precvsWaiting[tid] = precv
         self._join_one()
 
-    def join(self):
-        # type: () -> None
+    def join(self) -> None:
         while self._pworking:
             self._join_one()
 
-    def _join_one(self):
-        # type: () -> None
-        for tid, pipe in iteritems(self._precvs):
+    def _join_one(self) -> None:
+        for tid, pipe in self._precvs.items():
             if pipe.poll():
                 exc, logs, result = pipe.recv()
                 if exc:
@@ -136,8 +128,7 @@ class ParallelTasks(object):
             self._pworking += 1
 
 
-def make_chunks(arguments, nproc, maxbatch=10):
-    # type: (Sequence[unicode], int, int) -> List[Any]
+def make_chunks(arguments: Sequence[str], nproc: int, maxbatch: int = 10) -> List[Any]:
     # determine how many documents to read in one go
     nargs = len(arguments)
     chunksize = nargs // nproc
